


class_id = 1
class_names = ['person', 'bicycle']


for i in range(10):
    # check if class id is valid
    if (class_names != None) and (class_id >= len(class_names)):
        continue
    print("gggg")